@@ -99,6 +99,7 @@ impl<'a> MerkleRadixGetPathOperation for MerkleRadixOperations<'a, SqliteConnect
                   p.children,
                   '$[' || json_extract(?, '$[' || p.depth || ']') || ']'
                 )
+                AND c.tree_id = ?
             )
             SELECT t.hash, t.children, l.data, t.depth FROM tree_path t
             LEFT OUTER JOIN merkle_radix_leaf l ON t.leaf_id = l.id
@@ -113,6 +114,7 @@ impl<'a> MerkleRadixGetPathOperation for MerkleRadixOperations<'a, SqliteConnect
                 .map_err(|err| InternalError::from_source(Box::new(err)))?,
         )
         .bind::<BigInt, _>(tree_id)
+        .bind::<BigInt, _>(tree_id)
         .load::<SqliteExtendedMerkleRadixTreeNode>(self.conn)
         .map_err(|err| InternalError::from_source(Box::new(err)))?;
 
@@ -169,6 +171,7 @@ impl<'a> MerkleRadixGetPathOperation for MerkleRadixOperations<'a, PgConnection>
                 SELECT c.hash, c.tree_id, c.leaf_id, c.children, p.depth + 1
                 FROM merkle_radix_tree_node c, tree_path p
                 WHERE c.hash = p.children[$3[p.depth]]
+                AND c.tree_id = $2
             )
             SELECT t.hash, t.children, l.data, t.depth FROM tree_path t
             LEFT OUTER JOIN merkle_radix_leaf l ON t.leaf_id = l.id
@@ -271,7 +274,7 @@ mod tests {
 
         insert_into(merkle_radix_leaf::table)
             .values(NewMerkleRadixLeaf {
-                id: 1,
+                id: Some(1),
                 tree_id: 1,
                 address: "000000",
                 data: b"hello",
@@ -404,7 +407,7 @@ mod tests {
             let leaf_id = 1;
             insert_into(merkle_radix_leaf::table)
                 .values(NewMerkleRadixLeaf {
-                    id: leaf_id,
+                    id: Some(leaf_id),
                     tree_id: 1,
                     address: "000000",
                     data: b"hello",
